# OpenConfig

[**OpenConfig**](http://www.openconfig.net) is a collaborative effort by network
operators to develop programmatic interfaces and tools for managing networks in
a dynamic, vendor-neutral way.  OpenConfig’s initial focus is on compiling a
consistent set of vendor-neutral data models (written in
[YANG](http://datatracker.ietf.org/doc/rfc6020/)) based on actual operational
needs from use cases and requirements from multiple network operators.

## Contributing to OpenConfig

This repository is primarily for publishing the models, documents, and other
material developed by the OpenConfig operators group.

**We generally do not accept pull requests in this repository**.

Feedback and suggestions to improve OpenConfig models is welcomed on the
[public mailing list](https://groups.google.com/forum/?hl=en#!forum/netopenconfig),
or by opening a GitHub [issue](https://github.com/openconfig/public/issues).

## Joining OpenConfig

Please see the [OpenConfig web site](http://www.openconfig.net) for information
for operators wishing to join OpenConfig, in particular the
[FAQ for operators](http://openconfig.net/docs/faq-for-operators/).
